@@ -2,14 +2,14 @@ package Dancer2::Plugin::Auth::Extensible::Provider::ActiveDirectory;
 
 use feature qw/state/;
 use Carp qw/croak/;
-use Dancer2::Core::Types qw/HashRef Str Int ArrayRef/;
+use Dancer2::Core::Types qw/HashRef Str Int/;
 use Auth::ActiveDirectory;
 
 use Moo;
 with "Dancer2::Plugin::Auth::Extensible::Role::Provider";
 use namespace::clean;
 
-our $VERSION = '0.03.1';
+our $VERSION = '0.01';
 
 =head1 NAME
 
@@ -90,25 +90,26 @@ has principal => (
     required => 1,
 );
 
-=head2 allowed_groups
-
-List of groups allowed to login. If empty, all groups are allowed.
+=head1 METHODS
 
 =cut
 
-has allowed_groups => (
-    is      => 'ro',
-    isa     => ArrayRef,
-    default => sub { return [] },
-);
+sub _active_directory {
+    my $self = shift;
 
-=head1 METHODS
+    my $ad = Auth::ActiveDirectory->new(
+        host      => $self->host,
+        port      => $self->port,
+        timeout   => $self->timeout,
+        domain    => $self->domain,
+        principal => $self->principal,
+    ) || croak "ActiveDirectory connect failed for: " . $self->host;
+
+    return $ad;
+}
 
 =head2 authenticate_user $username, $password
 
-Returns true if the user could be authenticated. Returns also false if the user could be
-authenticated, but is member of any allowed group.
-
 =cut
 
 sub authenticate_user {
@@ -119,24 +120,11 @@ sub authenticate_user {
 
     my $ad = $self->_active_directory or return;
 
-    my $user = $ad->authenticate( $username, $password ) || return;
+    my $user = $ad->authenticate( $username, $password );
 
-    my $allowed = 1;
-    if ( @{ $self->allowed_groups } ) {
-        $allowed = 0;
-        for my $allowed_group ( @{ $self->allowed_groups } ) {
-            if (grep { $_ eq $allowed_group } map { $_->name } @{ $user->groups } ) {
-                $allowed = 1;
-                last;
-            }
-        }
-    }
+    $self->_user_cache($username, $user);
 
-    if ($allowed) {
-        $self->_user_cache($username, $user);
-        return 1;
-    }
-    return;
+    return !!$user;
 }
 
 =head2 get_user_details $username
@@ -182,35 +170,6 @@ sub get_user_roles {
     return [ map { $_->name } @{ $user->groups } ];
 }
 
-=head1 PRIVATE METHODS
-
-=head2 _active_directory
-
-Returns a connected L<Auth::ActiveDirectory> object.
-
-=cut
-
-sub _active_directory {
-    my $self = shift;
-
-    my $ad = Auth::ActiveDirectory->new(
-        host      => $self->host,
-        port      => $self->port,
-        timeout   => $self->timeout,
-        domain    => $self->domain,
-        principal => $self->principal,
-    ) || croak "ActiveDirectory connect failed for: " . $self->host;
-
-    return $ad;
-}
-
-=head2 _user_cache $username [, $value]
-
-Implements the user data cache. As we can only receive the user 
-information from L<Auth::ActiveDirectory> when authenticating,
-we save it in the cache and can use it when asked via the get_user_details or get_user_roles methods.
-
-=cut
 
 sub _user_cache {
     my ( $self, $username, $value ) = @_;
@@ -219,19 +178,14 @@ sub _user_cache {
     return $usercache->{$username} = $value;
 }
 
+
 1;
 
-=head1 TODO
-
-I was not able to create useful tests for this module. I tried to adopt the tests
-from L<Dancer2::Plugin::Auth::Extensible::Provider::LDAP>, but I was not able to fill
-the mock object with the correct data for the Test App to work. Please tell me if you
-can help out.
 
 
 =head1 AUTHOR
 
-Dominic Sonntag, C<< <dsonntag at cpan.org> >>
+Dominic Sonntag, C<< <dominic at s5g.de> >>
 
 =head1 BUGS
 
@@ -248,8 +202,28 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Dancer2::Plugin::Auth::Extensible::Provider::ActiveDirectory
 
-If you want to contribute to this module, write me an email or create a
-Pull request on Github: L<https://github.com/sonntagd/Dancer2-Plugin-Auth-Extensible-Provider-ActiveDirectory>
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dancer2-Plugin-Auth-Extensible-Provider-ActiveDirectory>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Dancer2-Plugin-Auth-Extensible-Provider-ActiveDirectory>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Dancer2-Plugin-Auth-Extensible-Provider-ActiveDirectory>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Dancer2-Plugin-Auth-Extensible-Provider-ActiveDirectory/>
+
+=back
 
 
 =head1 ACKNOWLEDGEMENTS
